package com.jianshui.api.controller.http.invoice.v1;

import com.alibaba.fastjson.JSONObject;
import com.jianshui.common.core.domain.AjaxResult;
import com.jianshui.common.core.domain.entity.Companyservice;
import com.jianshui.common.enums.ErrorCode;
import com.jianshui.common.utils.StringUtils;
import com.jianshui.invoice.service.ElephantInvoiceService;
import com.jianshui.system.service.ICompanyserviceService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/api/invoice/front/v1")
public class InvoiceFrontController {

    @Autowired
    private ICompanyserviceService iCompanyserviceService;

    @Autowired
    private ElephantInvoiceService elephantInvoiceService;


    /**
     * 数电登录接口(前端使用)
     */
    @ApiImplicitParams({
            @ApiImplicitParam(name = "identity", value = "身份认证", dataType = "java.lang.String", example = "1130", required = true),
            @ApiImplicitParam(name = "secret", value = "身份认证Key", dataType = "java.lang.String", example = "LTEO+oOgWMsuQAOUglqXuQ==", required = true),
            @ApiImplicitParam(name = "params", value = "请求体", dataType = "java.lang.String", required = true)
    })
    @PostMapping("/rpaLogin/{identity}/{secret}")
    public Object rpaLogin(@RequestBody Map<String,Object> params,@PathVariable("identity") String identity, @PathVariable("secret") String secret) {

        JSONObject paramJson = new JSONObject(params);

        log.debug("rpaLogin param{} identity:{} secret:{}", paramJson.toJSONString(), identity, secret);

        //参数校验
        if (StringUtils.isBlank(identity)){
            return AjaxResult.error("公司ID不能为空");
        }

        if (StringUtils.isBlank(secret)){
            return AjaxResult.error("公司Key不能为空");
        }


        if (StringUtils.isBlank(paramJson.getString("yhm"))){
            return AjaxResult.error("电子税局登录名不能为空");
        }

        if (StringUtils.isBlank(paramJson.getString("mm"))){
            return AjaxResult.error("电子税局密码不能为空");
        }
        //方法名处理
        if (StringUtils.isBlank(paramJson.getString("ffm"))){
            return AjaxResult.error("方法名不能为空");
        }

        if ("0".equals(paramJson.getString("ffm"))){
            paramJson.put("ffm","login");
        }
        if ("1".equals(paramJson.getString("ffm"))){
            paramJson.put("ffm","send_sms");
        }
        if ("2".equals(paramJson.getString("ffm"))){
            if (StringUtils.isBlank(paramJson.getString("zrrlx"))){
                return AjaxResult.error("责任人类型不能为空");
            }
            paramJson.put("ffm","select_zrrlx");
        }
        if ("3".equals(paramJson.getString("ffm"))){
            if (StringUtils.isBlank(paramJson.getString("dxyzm"))){
                return AjaxResult.error("短信验证码不能为空");
            }
            paramJson.put("ffm","sms_login");
        }

        Companyservice companyservice = iCompanyserviceService.selectCompanyserviceByIdentity(identity);
        if (companyservice == null || !secret.equals(companyservice.getSecret())) {
            return AjaxResult.error(ErrorCode.COMPANY_NOT_FOUND);
        }

        return elephantInvoiceService.rpaLogin(paramJson,companyservice);

    }


    /**
     * 数电账号查询接口(前端使用)
     */
    @ApiImplicitParams({
            @ApiImplicitParam(name = "identity", value = "身份认证", dataType = "java.lang.String", example = "1130", required = true),
            @ApiImplicitParam(name = "secret", value = "身份认证Key", dataType = "java.lang.String", example = "LTEO+oOgWMsuQAOUglqXuQ==", required = true)
    })
    @PostMapping("/queryRpaTaxAccount/{identity}/{secret}")
    public Object queryRpaTaxAccount(@PathVariable("identity") String identity, @PathVariable("secret") String secret ){

        log.debug("queryRpaTaxAccount param identity:{} secret:{}",identity,secret);
        //参数校验
        if (StringUtils.isBlank(identity)){
            return AjaxResult.error("公司ID不能为空");
        }

        if (StringUtils.isBlank(secret)){
            return AjaxResult.error("公司Key不能为空");
        }

        Companyservice companyservice = iCompanyserviceService.selectCompanyserviceByIdentity(identity);
        if (companyservice == null || !secret.equals(companyservice.getSecret())) {
            return AjaxResult.error(ErrorCode.COMPANY_NOT_FOUND);
        }

        return elephantInvoiceService.queryRpaTaxAccount(companyservice.getSellertax(),companyservice);

    }

    /**
     * 数电获取二维码接口(前端使用)
     */
    @ApiImplicitParams({
            @ApiImplicitParam(name = "identity", value = "身份认证", dataType = "java.lang.String", example = "1130", required = true),
            @ApiImplicitParam(name = "secret", value = "身份认证Key", dataType = "java.lang.String", example = "LTEO+oOgWMsuQAOUglqXuQ==", required = true),
            @ApiImplicitParam(name = "yhm", value = "电子税局登陆账号", dataType = "java.lang.String", required = true)
    })
    @PostMapping("/getRpaQrCode/{identity}/{secret}")
    public Object getRpaQrCode(@RequestBody Map<String,Object> params,@PathVariable("identity") String identity, @PathVariable("secret") String secret ) {

        JSONObject paramJson = new JSONObject(params);
        log.debug("getRpaQrCode param params:{} identity:{} secret:{}", paramJson,identity,secret);

        //参数校验
        if (StringUtils.isBlank(identity)){
            return AjaxResult.error("公司ID不能为空");
        }

        if (StringUtils.isBlank(secret)){
            return AjaxResult.error("公司Key不能为空");
        }

        if (StringUtils.isBlank(paramJson.getString("yhm"))){
            return AjaxResult.error("电子税局登录名不能为空");
        }

        Companyservice companyservice = iCompanyserviceService.selectCompanyserviceByIdentity(identity);

        if (companyservice == null || !secret.equals(companyservice.getSecret())) {
            return AjaxResult.error(ErrorCode.COMPANY_NOT_FOUND);
        }

        return elephantInvoiceService.getRpaQrCode(paramJson,companyservice);

    }


    /**
     * 数电登录接口(前端使用)
     */
    @ApiImplicitParams({
            @ApiImplicitParam(name = "identity", value = "身份认证", dataType = "java.lang.String", example = "1130", required = true),
            @ApiImplicitParam(name = "secret", value = "身份认证Key", dataType = "java.lang.String", example = "LTEO+oOgWMsuQAOUglqXuQ==", required = true),
            @ApiImplicitParam(name = "params", value = "请求体", dataType = "java.lang.String", required = true)
    })
    @PostMapping("/getRpaAuthStatus/{identity}/{secret}")
    public Object getRpaAuthStatus(@RequestBody Map<String,Object> params, @PathVariable("identity") String identity, @PathVariable("secret") String secret ) {

        JSONObject paramJson = new JSONObject(params);

        log.debug("getRpaAuthStatus param{} identity:{} secret:{}", paramJson.toJSONString(), identity, secret);

        //参数校验
        if (StringUtils.isBlank(identity)){
            return AjaxResult.error("公司ID不能为空");
        }

        if (StringUtils.isBlank(secret)){
            return AjaxResult.error("公司Key不能为空");
        }

        if (StringUtils.isBlank(paramJson.getString("rzid"))){
            return AjaxResult.error("认证ID不能为空");
        }

        Companyservice companyservice = iCompanyserviceService.selectCompanyserviceByIdentity(identity);
        if (companyservice == null || !secret.equals(companyservice.getSecret())) {
            return AjaxResult.error(ErrorCode.COMPANY_NOT_FOUND);
        }

        return elephantInvoiceService.getRpaAuthStatus(paramJson,companyservice);

    }


}
