package com.jianshui.invoice.service.impl;

import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.dxhy.order.protocol.invoke.DxhyInterfaceResponse;
import com.jianshui.common.constant.PersonList;
import com.jianshui.common.core.domain.AjaxResult;
import com.jianshui.common.core.domain.entity.Companyservice;
import com.jianshui.common.utils.JsonKeyCase;
import com.jianshui.invoice.constant.elephant.ElephantConstantsV6;
import com.jianshui.invoice.domain.dto.HXResponse;
import com.jianshui.invoice.service.ElephantInvoiceService;
import com.jianshui.invoice.utils.elephant.ElephantUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class ElephantInvoiceServiceImpl implements ElephantInvoiceService {

    //调用大象获取电子税局账号
    @Override
    public AjaxResult queryRpaTaxAccount(String sellertax, Companyservice companyservice) {

        Map<String,String> param = new HashMap<>();
        param.put("NSRSBH",sellertax);

        DxhyInterfaceResponse dxhyInterfaceResponse = null;
        try {
            log.info("front queryRpaTaxAccount param{}",JSONObject.toJSONString(param));
            dxhyInterfaceResponse = ElephantUtils.sendRequestWithoutTokenV6(ElephantConstantsV6.QUERY_RPA_TAX_ACCOUNT_LOCALHOST, ElephantConstantsV6.QUERY_RPA_TAX_ACCOUNT_METHOD, JSONUtil.parse(param), companyservice);
            log.info("front queryRpaTaxAccount response{}",JSONObject.toJSONString(dxhyInterfaceResponse));
        } catch (UnsupportedEncodingException | InvalidKeyException | NoSuchAlgorithmException e) {
            log.error("获取电子税局账号失败{}",e);
            return AjaxResult.error("009999", "系统异常！");
        }

        if (!"000000".equals(dxhyInterfaceResponse.getCode())){
            return AjaxResult.error(dxhyInterfaceResponse.getMessage());
        }

        JSONObject responJson = JSONObject.parseObject(dxhyInterfaceResponse.getData());
        responJson = JsonKeyCase.JsonKeyCase(responJson,1);
        if (!"000000".equals(responJson.getString("ztdm"))){
            return AjaxResult.error(responJson.getString("ztxx"));
        }
        return AjaxResult.success(responJson.getJSONArray("data"));
    }

    //调用大象进行登录
    @Override
    public AjaxResult rpaLogin(JSONObject paramJson, Companyservice companyservice) {

        paramJson.put("NSRSBH",companyservice.getSellertax());
        DxhyInterfaceResponse dxhyInterfaceResponse = null;
        try {
            paramJson = JsonKeyCase.JsonKeyCase(paramJson);
            log.info("front rpaLogin param{}",paramJson);
            dxhyInterfaceResponse = ElephantUtils.sendRequestWithoutTokenV6(ElephantConstantsV6.RPA_LOGIN_LOCALHOST, ElephantConstantsV6.RPA_LOGIN_METHOD, JSONUtil.parse(paramJson), companyservice);
            log.info("front rpaLogin response{}",JSONObject.toJSONString(dxhyInterfaceResponse));
        } catch (UnsupportedEncodingException | InvalidKeyException | NoSuchAlgorithmException e) {
            log.error("电子税局登陆失败{}",e);
            return  AjaxResult.error("009999", "系统异常！");
        }
        if (!"000000".equals(dxhyInterfaceResponse.getCode())){
            return AjaxResult.error(dxhyInterfaceResponse.getMessage());
        }
        //获取返回数据
        JSONObject responJson = JSONObject.parseObject(dxhyInterfaceResponse.getData());
        //key转成小写
        responJson = JsonKeyCase.JsonKeyCase(responJson,1);

        if (!"000000".equals(responJson.getString("ztdm"))){
            return AjaxResult.error(responJson.getString("ztxx"));
        }
        //判断后续方法是否为3
        JSONObject dataJson = responJson.getJSONObject("data");
        if ("2".equals(dataJson.getString("hxff"))){
            JSONObject sj = dataJson.getJSONObject("sj");
            List<String> personList = sj.getJSONArray("personList").toJavaList(String.class);
            Map<String,String> personTypes = new HashMap<>();
            personList.forEach(e->personTypes.put(e, PersonList.getName(e)));
            dataJson.put("personList",personTypes);
        }

        return AjaxResult.success(dataJson);
    }

    //获取二维码
    @Override
    public AjaxResult getRpaQrCode(JSONObject paramJson, Companyservice companyservice) {

        paramJson.put("NSRSBH",companyservice.getSellertax());
        DxhyInterfaceResponse dxhyInterfaceResponse = null;
        try {
            paramJson = JsonKeyCase.JsonKeyCase(paramJson);
            log.info("front getRpaQrCode param{}",JSONObject.toJSONString(paramJson));
            dxhyInterfaceResponse = ElephantUtils.sendRequestWithoutTokenV6(ElephantConstantsV6.GET_RPA_QY_CODE_LOCALHOST, ElephantConstantsV6.GET_RPA_QY_CODE_METHOD, JSONUtil.parse(paramJson), companyservice);
            log.info("front getRpaQrCode response{}",JSONObject.toJSONString(dxhyInterfaceResponse));
        } catch (UnsupportedEncodingException | InvalidKeyException | NoSuchAlgorithmException e) {
            log.error("电子税局登陆失败{}",e);
            return  AjaxResult.error("009999", "系统异常！");
        }
        if (!"000000".equals(dxhyInterfaceResponse.getCode())){
            return AjaxResult.error(dxhyInterfaceResponse.getMessage());
        }
        JSONObject responJson = JSONObject.parseObject(dxhyInterfaceResponse.getData());
        responJson = JsonKeyCase.JsonKeyCase(responJson,1);

        if (!"000000".equals(responJson.getString("ztdm"))){
            return AjaxResult.error(responJson.getString("ztxx"));
        }
        return AjaxResult.success(responJson.getJSONObject("data"));
    }

    //数电实名认证状态
    @Override
    public AjaxResult getRpaAuthStatus(JSONObject paramJson, Companyservice companyservice) {
        paramJson.put("NSRSBH",companyservice.getSellertax());
        DxhyInterfaceResponse dxhyInterfaceResponse = null;
        try {
            paramJson = JsonKeyCase.JsonKeyCase(paramJson);
            log.info("front getRpaAuthStatus param{}",paramJson);
            dxhyInterfaceResponse = ElephantUtils.sendRequestWithoutTokenV6(ElephantConstantsV6.GET_RPA_AUTH_STATUS_LOCALHOST, ElephantConstantsV6.GET_RPA_AUTH_STATUS_METHOD, JSONUtil.parse(paramJson), companyservice);
            log.info("front getRpaAuthStatus response{}",JSONObject.toJSONString(dxhyInterfaceResponse));
        } catch (UnsupportedEncodingException | InvalidKeyException | NoSuchAlgorithmException e) {
            log.error("电子税局登陆失败{}",e);
            return  AjaxResult.error("009999", "系统异常！");
        }
        if (!"000000".equals(dxhyInterfaceResponse.getCode())){
            return AjaxResult.error(dxhyInterfaceResponse.getMessage());
        }
        JSONObject responJson = JSONObject.parseObject(dxhyInterfaceResponse.getData());
        responJson = JsonKeyCase.JsonKeyCase(responJson,1);

        if (!"000000".equals(responJson.getString("ztdm"))){
            return AjaxResult.error(responJson.getString("ztxx"));
        }
        return AjaxResult.success(responJson.getJSONObject("data"));
    }
}
